@@ -1,4 +1,4 @@
-from quick_resto_objects.quick_resto_object import QuickRestoObject
+from quick_resto_API.quick_resto_objects.quick_resto_object import QuickRestoObject
 
 
 class Group(QuickRestoObject):
