@@ -1,4 +1,4 @@
-from quick_resto_API.quick_resto_objects.modules.front.table import Table
+from quick_resto_API.quick_resto_objects.modules.front.table_scheme import TableScheme
 from quick_resto_API.quick_resto_objects.modules.front.terminal import Terminal
 from quick_resto_API.quick_resto_objects.modules.front.shift import Shift
 from quick_resto_API.quick_resto_objects.modules.personnel.employee import Employee
@@ -35,35 +35,35 @@ class OrderInfo(QuickRestoObject):
         return self._front
 
     @property
-    def front_sum(self) -> int:
+    def front_sum(self) -> float:
         return self._front_sum
 
     @property
-    def front_total_absolute_charge(self) -> int:
+    def front_total_absolute_charge(self) -> float:
         return self._front_total_absolute_charge
 
     @property
-    def front_total_absolute_discount(self) -> int:
+    def front_total_absolute_discount(self) -> float:
         return self._front_total_absolute_discount
 
     @property
-    def front_total_bonuses(self) -> int:
+    def front_total_bonuses(self) -> float:
         return self._front_total_bonuses
 
     @property
-    def front_total_card(self) -> int:
+    def front_total_card(self) -> float:
         return self._front_total_card
 
     @property
-    def front_total_cash_minus_discount(self) -> int:
+    def front_total_cash_minus_discount(self) -> float:
         return self._front_total_cash_minus_discount
 
     @property
-    def front_total_discount(self) -> int:
+    def front_total_discount(self) -> float:
         return self._front_total_discount
 
     @property
-    def front_total_price(self) -> int:
+    def front_total_price(self) -> float:
         return self._front_total_price
 
     @property
@@ -99,15 +99,15 @@ class OrderInfo(QuickRestoObject):
         return self._shift_id
 
     @property
-    def table(self) -> Table:
-        return self._table
+    def table_scheme(self) -> TableScheme:
+        return self._table_scheme
 
     @property
     def table_order_doc_id(self) -> str:
         return self._table_order_doc_id
 
     @property
-    def total_sum(self) -> int:
+    def total_sum(self) -> float:
         return self._total_sum
 
     @property
@@ -115,15 +115,15 @@ class OrderInfo(QuickRestoObject):
         return self._waiter
 
     def __init__(self, comment: str = None, createDate: str = None, documentNumber: int = None,
-                 discountPercent: int = None, cashier: dict = None, extId: str = None,
-                 front: dict = None, frontSum: int = None, frontTotalAbsoluteCharge: int = None,
-                 frontTotalAbsoluteDiscount: int = None, frontTotalBonuses: int = None,
-                 frontTotalCard: int = None, frontTotalCashMinusDiscount: int = None, frontTotalDiscount: int = None,
-                 frontTotalPrice: int = None,
+                 discountPercent: float = None, cashier: dict = None, extId: str = None,
+                 front: dict = None, frontSum: float = None, frontTotalAbsoluteCharge: float = None,
+                 frontTotalAbsoluteDiscount: float = None, frontTotalBonuses: float = None,
+                 frontTotalCard: float = None, frontTotalCashMinusDiscount: float = None, frontTotalDiscount: float = None,
+                 frontTotalPrice: float = None,
                  kkmTerminalName: str = None, originalOrderDocId: str = None, precheckDocId: str = None,
                  reopenedOrderDocId: str = None, returned: bool = None,
-                 returnOrderDocId: str = None, shift: dict = None, shiftId: str = None, table: dict = None,
-                 tableOrderDocId: str = None, totalSum: int = None,
+                 returnOrderDocId: str = None, shift: dict = None, shiftId: str = None, tableScheme: dict = None,
+                 tableOrderDocId: str = None, totalSum: float = None,
                  waiter: dict = None, **kwargs):
         class_name = "ru.edgex.quickresto.modules.front.orders.OrderInfo"
 
@@ -132,9 +132,9 @@ class OrderInfo(QuickRestoObject):
         self._comment: str = comment
         self._create_date: str = createDate
         self._document_number: int = documentNumber
-        self._discount_percent: int = discountPercent
+        self._discount_percent: float = discountPercent
         
-        if cashier is not None: 
+        if cashier is not None:
             self._cashier = Employee(**cashier)
         else:
             self._cashier = None
@@ -146,14 +146,14 @@ class OrderInfo(QuickRestoObject):
         else:
             self._front = None
 
-        self._front_sum: int = frontSum
-        self._front_total_absolute_charge: int = frontTotalAbsoluteCharge
-        self._front_total_absolute_discount: int = frontTotalAbsoluteDiscount
-        self._front_total_bonuses: int = frontTotalBonuses
-        self._front_total_card: int = frontTotalCard
-        self._front_total_cash_minus_discount: int = frontTotalCashMinusDiscount
-        self._front_total_discount: int = frontTotalDiscount
-        self._front_total_price: int = frontTotalPrice
+        self._front_sum: float = frontSum
+        self._front_total_absolute_charge: float = frontTotalAbsoluteCharge
+        self._front_total_absolute_discount: float = frontTotalAbsoluteDiscount
+        self._front_total_bonuses: float = frontTotalBonuses
+        self._front_total_card: float = frontTotalCard
+        self._front_total_cash_minus_discount: float = frontTotalCashMinusDiscount
+        self._front_total_discount: float = frontTotalDiscount
+        self._front_total_price: float = frontTotalPrice
         self._kkm_terminal_name: str = kkmTerminalName
         self._original_order_doc_id: str = originalOrderDocId
         self._precheck_doc_id: str = precheckDocId
@@ -168,13 +168,13 @@ class OrderInfo(QuickRestoObject):
 
         self._shift_id: str = shiftId
         
-        if table is not None: 
-            self._table = Table(**table)
+        if tableScheme is not None: 
+            self._table_scheme = TableScheme(**tableScheme)
         else:
-            self._table = None
+            self._table_scheme = None
 
         self._table_order_doc_id: str = tableOrderDocId
-        self._total_sum: int = totalSum
+        self._total_sum: float = totalSum
 
         if waiter is not None: 
             self._waiter = Employee(**waiter)
